@@ -1,10 +1,6 @@
 # This file contains functions to call phyclust_find_consensus() in C.
 
 find.consensus <- function(X, code.type = .code.type[1], with.gap = FALSE){
-  if(! is.matrix(X)){
-    stop("X is not a matrix.")
-  }
-
   code.type <- which(code.type == .code.type) - 1
 
   ret <- .Call("R_phyclust_find_consensus",
