@@ -1,7 +1,7 @@
 ### This file contains function to show all possible options in phyclust.
 
 .show.option <- function(){
-  my.cat("Options available in phyclust:")
+  my.cat("Options available in phyclust:", "\n")
   my.cat("boundary method: ", paste(.boundary.method, collapse = ", "), "\n")
   my.cat("code type: ", paste(.code.type, collapse = ", "), "\n")
   my.cat("edist model: ", paste(.edist.model, collapse = ", "), "\n")
@@ -13,6 +13,6 @@
   my.print(as.matrix(.nucleotide))
   my.print(as.matrix(.snp))
   my.cat("substitution model: \n")
-  my.print(as.matrix(.substitution))
+  my.print(as.matrix(.substitution.model))
   invisible()
 } # End of .show.option()
