@@ -205,7 +205,8 @@ SEXP initialize_emptr(EMPTR emptr, phyclust_struct *pcs){
 
 	emptr->C_protect_length = 4 + emobj_length + QA_length + converge_length;
 
-	UNPROTECT(emptr->C_protect_length);
+	/* Do NOT call UNPROTECT() within this constructor!! */
+	// UNPROTECT(emptr->C_protect_length);
 	return(emobj);
 } /* End of initialize_emptr(). */
 
